From: Jaipaul Cheernam <jaipaul.cheernam@est.tech>
To: Alexander Kanavin <alex.kanavin@gmail.com>,
Trevor Gamblin <tgamblin@baylibre.com>
Cc: openembedded-core@lists.openembedded.org
Subject: Re: [OE-core] [PATCH v2] python3-more-itertools: upgrade 10.8.0 -> 11.1.0
Date: Wed, 14 Oct 2026 19:53:52 +0200 [thread overview]
Message-ID: <041c3f63-1951-4bc0-9961-ea6a09d41f9f@est.tech> (raw)
In-Reply-To: <CANNYZj_jMnU7HKc+F-WF7NooAG587zM=E=ucPrxKTXaCouRNxQ@mail.gmail.com>
On 2026-10-12 19:10, Alexander Kanavin wrote:
> The consensus in the patch review was that a nearly 100x time increase in
> TCG vs. real silicon is still pathological and needs to be investigated
> (assuming all targets run exact same test code). So can you look into that,
> perhaps with guidance from Trevor (or maybe Trevor can also check what is
> happening)?
>
> Also a 1800s timeout when the test takes 1702s is too close, and that can
> easily go over on loaded autobuilder machines. For reliability, it would
> need to be at least double what you observe. But if we don't make progress
> with figuring out the slowness, we should probably disable the specific
> slow test, rather than let it run for 30 minutes.
Hi Alex,
The actual test is 100 threads × 100,000 elements (10M lock-guarded
next() calls)
I did tests with different config combinations , total work fixed at
1,000,000 next() calls and varied only the thread count:
config native x86-64 qemuriscv64 TCG slowdown
10 threads x 100k 1.35s 15.5s ~11x
100 threads x 10k 0.10s 110.5s ~1100x
Trevor, do you have any suggestions how we can handle this situation ?
If no other options, I will disable the specific slow test .
next prev parent reply other threads:[~2026-10-14 17:54 UTC|newest]
Thread overview: 11+ messages / expand[flat|nested] mbox.gz Atom feed top
2026-10-07 5:58 [PATCH 1/6] cups: upgrade 2.4.19 -> 2.4.20 Jaipaul Cheernam
2026-10-07 5:58 ` [PATCH 2/6] harfbuzz: upgrade 14.5.1 -> 14.6.0 Jaipaul Cheernam
2026-10-07 5:58 ` [PATCH 3/6] rpm-sequoia-crypto-policy: upgrade to latest revision Jaipaul Cheernam
2026-10-07 5:58 ` [PATCH 4/6] python3-hypothesis: upgrade 6.168.3 -> 6.168.5 Jaipaul Cheernam
2026-10-07 5:58 ` [PATCH 5/6] python3-more-itertools: upgrade 10.8.0 -> 11.1.0 Jaipaul Cheernam
2026-10-07 14:23 ` [OE-core] " Mathieu Dubois-Briand
2026-10-08 7:21 ` Trevor Gamblin
2026-10-08 18:21 ` [PATCH v2] " Jaipaul Cheernam
2026-10-12 17:10 ` [OE-core] " Alexander Kanavin
2026-10-14 17:53 ` Jaipaul Cheernam [this message]
2026-10-07 5:58 ` [PATCH 6/6] python3-rpds-py: upgrade 2026.6.3 -> 2026.9.1 Jaipaul Cheernam
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=041c3f63-1951-4bc0-9961-ea6a09d41f9f@est.tech \
--to=jaipaul.cheernam@est.tech \
--cc=alex.kanavin@gmail.com \
--cc=openembedded-core@lists.openembedded.org \
--cc=tgamblin@baylibre.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox